%         This file contains the matlab code to solve the
%         system of ODEs describing the spring on a pendulum.

%         Also need file SprPend.m

%              Prof. J. Strikwerda  Jan. 4, 2000

% Clear variables.
clear
clf 

% Global variables are needed to get information to the function pendulum.
global GG
global LL
global KK

% Get the pendulum configuration from the user.
disp('Type in the natural length, and spring constant, enclosed in [ ]s, e.g., [1 10 ]. ');
reply = input('  ');

% Set the global variables.
LL = reply(1);
KK = reply(2);

GG   = 9.8;
% Acceleration of gravity in meters/sec^2

hanglength = LL + GG/KK

% Set the initial and final time.
t0       =  0.0;
tfinal   = 10.0;

% Set the initial conditions.  The user specifies radius and theta, and
% we'll assume that the pendulum starts at rest, so the "dot" variables are 0.

disp('Type in the initial values for r and theta, enclosed in [ ]s ');
disp('Values of theta should be entered in radians.  For example, [ 1  pi/4 ]');
reply = input('  ');

radius0   = reply(1);
theta0    = reply(2);
radiusdot0= 0.;
thetadot0 = 0.;

% Put in standard form  z' = f( t, z ) 
z0 = [ radius0, theta0, radiusdot0, thetadot0 ];

disp('Wait, this may take a while...' );

% Now solve it!  Use Matlab's automatic ODE solver, ode45.
% The function  SpringPendulumODE  is in the file SpringPendulumODE.m

options= odeset( 'RelTol', 1.e-7 ) ;
tspan = [t0, tfinal];
[t,z] = ode45('SpringPendulumODE', tspan, z0, options );

% Plot the variables radius, theta, radius', theta' as functions of t .
plot( t, z );

disp(' ');
disp('This first plot shows the variation of radius, theta, radiusdot, and thetadot');
disp('as functions of t. ');
disp(' ');
disp('Hit any key to continue...');
pause;

% Plot the initial conditions and the solution in the (x,y) plane.

% Get the two angles.
radius = z(:,1);
theta  = z(:,2);

% Compute the positions of the pendulum.  (x0,y0) is the position for all the times.

x0 =  radius.* sin( theta );
y0 = -radius.* cos( theta );

% Compute the initial position.
initx = [ 0, x0(1) ];
inity = [ 0, y0(1) ];

plot( initx, inity, 'o', initx, inity, x0, y0, 0., -hanglength, '+' );

% The axes are set to have all the plots be on the same axes.
yhi = max( y0' )*1.5 ;
ylo = min( y0' )*1.5 ;
xlo = -(yhi - ylo)/2 ;
xhi = -xlo ;
axis( [ xlo, xhi, ylo, yhi ] );

% Have the axes have the same length scales.
axis( 'square' );

disp(' ');
disp('This second plot shows the path of the pendulum mass in time.');
disp('Also shown is the initial position of the pendulum.');
disp('The + sign shows the position where the pendulum would be if it were to simply hang.');


% Ask the user if we should show the movie.

yesno = input('See the movie for this motion?  (0 = no, 1 = yes): ');
if yesno == 1
    
    disp('Wait, making movies takes some space and time ' )
    
    % Free up some space for the movie storage
    clear z;
    
    % Number of time steps.  
    N = length(t);
    
    % Allocate space for the movie frames.
    % We will take only every third time step.
    MM = floor((N+2)/3 + 0.1 );
    M = moviein(MM);
    fprintf('Movie length = %d frames. ', MM);
    
    % Make the movie.  Each kk produces a frame.
    % The frames are stored by M(:,kk) = getframe;
    kk = 1; 
    for k = 1:3:N
        x = [ 0, x0(k) ];
        y = [ 0, y0(k) ];
        plot( x, y, 'o', x, y ,x0(1:k),y0(1:k),'r');
        axis( [ xlo, xhi, ylo, yhi ] );
        axis( 'square' );
        text(.5*xhi,.5*yhi,sprintf('t = %5.3f',t(k)));
        M(:,kk) = getframe;
        kk = kk + 1;
    end
    
    % display it again.
    disp(' ' );
    disp('The movie will be shown again, hit control C to kill it. ' );
    disp('Type movie(M) to see the movie again ');
    
    movie(M,1);
    
end

