function zp = CompoundPendulumODE(t, z) 

%  function CompoundPendulumODE
%  The purpose of this function is to calculate the derivative of:
%    z = [ alpha , beta, alphadot, betadot ]
%
%  which we will call zp.  So,
%    zp = [ alphadot, betadot, alphadotdot,betadotdot ]
%
%  The values of radiusdot and thetadot are given in z, so we really
%  only need to find radiusdotdot and thetadotdot.
%
%  We have to find these using the given differential equations.
%  To put the equations in standard form, we'd solve the two equations
%  simultaneously for these two variables (radiusdotdot and thetadotdot).
%

% These are the global variables.

global GG
global L0
global L1
global L2
global M1
global M2
global BB

L0 = 1;
% length given in the question

GG   = 9.8;
% Acceleration of gravity in meters/sec^2

BB = ((M1 * L1) - (M2 * L2)) / (M1 + M2);
% measure of how balanced the two masses are around the pivot point.

% Convert from standard form to meaningful names.

alpha    = z(1) ;
beta     = z(2) ;
alphadot = z(3) ;
betadot  = z(4) ;

% Compute the dot-dot variables.
X = BB * cos(alpha - beta);
Y = BB * sin(alpha - beta);
Z = (M1 * L1^2 + M2 * L2^2)/(L0*(M1 + M2));
U = -GG*sin(alpha) - Y * (betadot^2);
V = (-GG*BB*sin(beta))/L0 + Y * (alphadot^2);

% put them in to matrix and use "\" to solve the equation

AA = [L0 X; X Z];
CC = [U ; V];

BB = AA\CC;

alphadotdot = BB(1) ;
betadotdot  = BB(2) ;

% Convert back to standard form.
% Note that the variables in zp correspond to the dots of the
% variables in z.

zp = [ alphadot; betadot; alphadotdot; betadotdot ];

